================
python-lexoffice
================


.. image:: https://img.shields.io/pypi/v/lexoffice.svg
        :target: https://pypi.python.org/pypi/lexoffice

.. image:: https://img.shields.io/travis/schaenzer/lexoffice.svg
        :target: https://travis-ci.org/schaenzer/lexoffice

.. image:: https://readthedocs.org/projects/lexoffice/badge/?version=latest
        :target: https://lexoffice.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/schaenzer/lexoffice/shield.svg
     :target: https://pyup.io/repos/github/schaenzer/lexoffice/
     :alt: Updates



A Python library for interacting with the lexoffice Public API


* Free software: MIT license
* Documentation: https://lexoffice.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
